/*
 *  Copyright (c) 2002-2003 Jesper K. Pedersen <blackie@kde.org>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 **/
#ifndef CHARSELECTOR_H
#define CHARSELECTOR_H

#include <qwidget.h>

class QComboBox;
class QWidgetStack;
class LimitedCharLineEdit;

class CharSelector :public QWidget
{
    Q_OBJECT

public:
    CharSelector( QWidget* parent, const char* name = 0 );
    QString text() const;
    void setText( QString text );
    bool isEmpty() const;

protected:
    void fillComboBox();

private slots:
    void slotNewItem( int which );

private:
    QComboBox* _type;
    QWidgetStack* _stack;
    LimitedCharLineEdit* _normal;
    LimitedCharLineEdit* _hex;
    LimitedCharLineEdit* _oct;
    int _oldIndex;
};

#endif // CHARSELECTOR_H
